# coding: utf-8

u"""Модуль, содержащий валидаторы запросов в ФМС."""

from objectpack.exceptions import ValidationError


class BaseFmsValidator(object):
    u"""Базовый валидатор."""

    def __init__(self):
        self.required_params = NotImplemented

    def validate(self, params):
        u"""Выполняет валидацию переданных параметров.

        :param dict params: Словарь с параметрами запроса
        """

        for param in self.required_params:
            if not params.get(param, False):
                raise ValidationError(
                    u'Не указан обязательный параметр {0}'.format(param)
                )


class ConfigValidator(BaseFmsValidator):
    u"""Класс для проверки параметров запроса bookRequest."""

    def __init__(self):
        super(ConfigValidator, self).__init__()
        self.required_params = [
            'wsdl_url',
            'certificate_path',
            'private_key_path',
            'private_key_pass',
            'smev_sender_code',
            'smev_sender_name',
            'recipient_code',
            'recipient_name',
            'system_okato',
            'region_code',
            'service_code',
            'user_id',
            'user_iname',
            'user_oname',
            'user_fname',
            'DIGEST_METHOD',
            'TYPE_CODE',
            'EXCHANGE_TYPE',
            'MESSAGE_STATUS',
            'VERSION_CODE',
        ]

    def validate(self, config):
        u"""Выполняет проверку настроек.

        :param config: настройки обмена с ФМС
        """

        for param in self.required_params:
            if getattr(config, param, None) is None:
                raise ValidationError(
                    u'Не указан обязательный параметр {0}'.format(param)
                )


class BookRequestValidator(BaseFmsValidator):
    u"""Класс для проверки параметров запроса bookRequest."""

    def __init__(self):
        super(BookRequestValidator, self).__init__()
        self.required_params = [
            'CITIZEN_LASTNAME',
            'CITIZEN_FIRSTNAME',
            'CITIZEN_BIRTHDAY',
            'DOC_TYPE',
            'DOC_SERIE',
            'DOC_NUMBER',
            'DOC_ISSUEDATE',
            'REGION_CODE',
            'LPLACE_REGION',
            'LPLACE_CITY',
            'LPLACE_STREET',
            'LPLACE_HOUSE',
            'LPLACE_FLAT'
        ]


class GetResultValidator(BaseFmsValidator):
    u"""Класс для проверки параметров запроса getResult."""

    def __init__(self):
        super(GetResultValidator, self).__init__()
        self.required_params = [
            'RequestIdRef',
            'OriginRequestIdRef',
            'taskId',
        ]
